@@ -150,8 +150,13 @@ class Settable:
         :param completer: tab completion function that provides choices for this argument
         """
         if val_type == bool:
+
+            def get_bool_choices(_) -> List[str]:  # type: ignore[no-untyped-def]
+                """Used to tab complete lowercase boolean values"""
+                return ['true', 'false']
+
             val_type = str_to_bool
-            choices = ['true', 'false']
+            choices_provider = cast(ChoicesProviderFunc, get_bool_choices)
 
         self.name = name
         self.val_type = val_type
@@ -176,10 +181,17 @@ class Settable:
         :param value: New value to set
         :return: New value that the attribute was set to
         """
+        # Run the value through its type function to handle any conversion or validation
+        new_value = self.val_type(value)
+
+        # Make sure new_value is a valid choice
+        if self.choices is not None and new_value not in self.choices:
+            choices_str = ', '.join(map(repr, self.choices))
+            raise ValueError(f"invalid choice: {new_value!r} (choose from {choices_str})")
+
         # Try to update the settable's value
         orig_value = self.get_value()
-        setattr(self.settable_obj, self.settable_attrib_name, self.val_type(value))
-        new_value = getattr(self.settable_obj, self.settable_attrib_name)
+        setattr(self.settable_obj, self.settable_attrib_name, new_value)
 
         # Check if we need to call an onchange callback
         if orig_value != new_value and self.onchange_cb:
@@ -589,7 +601,7 @@ class ProcReader:
 
         self._out_thread = threading.Thread(name='out_thread', target=self._reader_thread_func, kwargs={'read_stdout': True})
 
-        self._err_thread = threading.Thread(name='out_thread', target=self._reader_thread_func, kwargs={'read_stdout': False})
+        self._err_thread = threading.Thread(name='err_thread', target=self._reader_thread_func, kwargs={'read_stdout': False})
 
         # Start the reader threads for pipes only
         if self._proc.stdout is not None:
@@ -775,17 +787,23 @@ def align_text(
     if width < 1:
         raise ValueError("width must be at least 1")
 
-    # Handle tabs
+    # Convert tabs to spaces
     text = text.replace('\t', ' ' * tab_width)
     fill_char = fill_char.replace('\t', ' ')
 
-    if len(ansi.strip_style(fill_char)) != 1:
+    # Save fill_char with no styles for use later
+    stripped_fill_char = ansi.strip_style(fill_char)
+    if len(stripped_fill_char) != 1:
         raise TypeError("Fill character must be exactly one character long")
 
     fill_char_width = ansi.style_aware_wcswidth(fill_char)
     if fill_char_width == -1:
         raise (ValueError("Fill character is an unprintable character"))
 
+    # Isolate the style chars before and after the fill character. We will use them when building sequences of
+    # of fill characters. Instead of repeating the style characters for each fill character, we'll wrap each sequence.
+    fill_char_style_begin, fill_char_style_end = fill_char.split(stripped_fill_char)
+
     if text:
         lines = text.splitlines()
     else:
@@ -798,23 +816,6 @@ def align_text(
     # This also allows the lines to be used independently and still have their style. TableCreator does this.
     aggregate_styles = ''
 
-    # Save the ANSI style sequences in fill_char
-    fill_char_styles = get_styles_in_text(fill_char)
-
-    # Create a space with the same style as fill_char for cases in which
-    # fill_char does not divide evenly into the gap.
-    styled_space = ''
-    char_index = 0
-    while char_index < len(fill_char):
-        if char_index in fill_char_styles:
-            # Preserve this style in styled_space
-            styled_space += fill_char_styles[char_index]
-            char_index += len(fill_char_styles[char_index])
-        else:
-            # We've reached the visible fill_char. Replace it with a space.
-            styled_space += ' '
-            char_index += 1
-
     for index, line in enumerate(lines):
         if index > 0:
             text_buf.write('\n')
@@ -848,23 +849,23 @@ def align_text(
             right_fill_width = 0
 
         # Determine how many fill characters are needed to cover the width
-        left_fill = (left_fill_width // fill_char_width) * fill_char
-        right_fill = (right_fill_width // fill_char_width) * fill_char
+        left_fill = (left_fill_width // fill_char_width) * stripped_fill_char
+        right_fill = (right_fill_width // fill_char_width) * stripped_fill_char
 
         # In cases where the fill character display width didn't divide evenly into
-        # the gap being filled, pad the remainder with styled_space.
-        left_fill += styled_space * (left_fill_width - ansi.style_aware_wcswidth(left_fill))
-        right_fill += styled_space * (right_fill_width - ansi.style_aware_wcswidth(right_fill))
+        # the gap being filled, pad the remainder with space.
+        left_fill += ' ' * (left_fill_width - ansi.style_aware_wcswidth(left_fill))
+        right_fill += ' ' * (right_fill_width - ansi.style_aware_wcswidth(right_fill))
 
-        # Don't allow styles in fill_char and text to affect one another
-        if fill_char_styles or aggregate_styles or line_styles:
+        # Don't allow styles in fill characters and text to affect one another
+        if fill_char_style_begin or fill_char_style_end or aggregate_styles or line_styles:
             if left_fill:
-                left_fill = ansi.RESET_ALL + left_fill
-            left_fill += ansi.RESET_ALL
+                left_fill = ansi.TextStyle.RESET_ALL + fill_char_style_begin + left_fill + fill_char_style_end
+            left_fill += ansi.TextStyle.RESET_ALL
 
             if right_fill:
-                right_fill = ansi.RESET_ALL + right_fill
-            right_fill += ansi.RESET_ALL
+                right_fill = ansi.TextStyle.RESET_ALL + fill_char_style_begin + right_fill + fill_char_style_end
+            right_fill += ansi.TextStyle.RESET_ALL
 
         # Write the line and restore any styles from previous lines
         text_buf.write(left_fill + aggregate_styles + line + right_fill)
@@ -953,8 +954,8 @@ def truncate_line(line: str, max_width: int, *, tab_width: int = 4) -> str:
     If there are ANSI style sequences in the string after where truncation occurs, this function will append them
     to the returned string.
 
-    This is done to prevent issues caused in cases like: truncate_line(fg.blue + hello + fg.reset, 3)
-    In this case, "hello" would be truncated before fg.reset resets the color from blue. Appending the remaining style
+    This is done to prevent issues caused in cases like: truncate_line(Fg.BLUE + hello + Fg.RESET, 3)
+    In this case, "hello" would be truncated before Fg.RESET resets the color from blue. Appending the remaining style
     sequences makes sure the style is in the same state had the entire string been printed. align_text() relies on this
     behavior when preserving style over multiple lines.
 
