@@ -10,7 +10,7 @@ import cmd2
 
 
 class ReplWithExitCode(cmd2.Cmd):
-    """ Example cmd2 application where we can specify an exit code when existing."""
+    """Example cmd2 application where we can specify an exit code when existing."""
 
     def __init__(self):
         super().__init__()
@@ -19,23 +19,23 @@ class ReplWithExitCode(cmd2.Cmd):
     def do_exit(self, arg_list: List[str]) -> bool:
         """Exit the application with an optional exit code.
 
-Usage:  exit [exit_code]
-    Where:
-        * exit_code - integer exit code to return to the shell
-"""
+        Usage:  exit [exit_code]
+            Where:
+                * exit_code - integer exit code to return to the shell"""
         # If an argument was provided
         if arg_list:
             try:
                 self.exit_code = int(arg_list[0])
             except ValueError:
                 self.perror("{} isn't a valid integer exit code".format(arg_list[0]))
-                self.exit_code = -1
+                self.exit_code = 1
 
         return True
 
 
 if __name__ == '__main__':
     import sys
+
     app = ReplWithExitCode()
     sys_exit_code = app.cmdloop()
     app.poutput('{!r} exiting with code: {}'.format(sys.argv[0], sys_exit_code))
